@@ -272,29 +272,29 @@ def differential_abundance_analysis(dataset, heatmapALL, labels, IndexAndClass,i
             pred_Confidence_dict['Class'] = [i[2][0] for i in IndexAndClass]
             
             save_dict_to_excel(pred_Confidence_dict, dataset.bioInsights_dir_abundance_analysis+'Prediction_Confidence.xlsx')                        
-            df_PC =  pd.DataFrame.from_dict(pred_Confidence_dict)            
-            df_PIR = pd.DataFrame.from_dict(RestrictedModelData)
+            # df_PC =  pd.DataFrame.from_dict(pred_Confidence_dict)            
+            # df_PIR = pd.DataFrame.from_dict(RestrictedModelData)
 
             # Order Subgroups_of_patients_labels
-            listt=list(range(max(set(Subgroups_of_patients_labels))+1))
-            strt = 0
-            for i in set(Subgroups_of_patients_labels):
-                listt[i] = strt
-                strt+=1
-            Subgroups_of_patients_labels = [listt[spl] for spl in Subgroups_of_patients_labels]
-            cp = sns.color_palette("bright",len(set(Subgroups_of_patients_labels)))
-            Subgroups_of_patients_labels_colors = [cp[spl-1] for spl in Subgroups_of_patients_labels]
-            names = list(Subgroups_of_patients_labels_names.keys()) 
+            # listt=list(range(max(set(Subgroups_of_patients_labels))+1))
+            # strt = 0
+            # for i in set(Subgroups_of_patients_labels):
+            #     listt[i] = strt
+            #     strt+=1
+            # Subgroups_of_patients_labels = [listt[spl] for spl in Subgroups_of_patients_labels]
+            # cp = sns.color_palette("bright",len(set(Subgroups_of_patients_labels)))
+            # Subgroups_of_patients_labels_colors = [cp[spl-1] for spl in Subgroups_of_patients_labels]
+            # names = list(Subgroups_of_patients_labels_names.keys()) 
             
-            # Display PIR's per patient.
-            plt.close()
-            plt.figure()
-            labels_pal = sns.cubehelix_palette(len(set(list_labels)), light=.9, dark=.1, reverse=True, start=0, rot=-2)
-            labels_lut = dict(zip(map(str, list(set(list_labels))), labels_pal))        
-            labels_colors = [labels_lut[str(k)] for k in list_labels]
-            cm_PIR = sns.clustermap(df_PIR,col_cluster=False,row_cluster=True, xticklabels=1, vmin=1, vmax=1.3, row_colors=[Subgroups_of_patients_labels_colors,labels_colors], linewidths=0, cmap="magma")
+            # # Display PIR's per patient.
+            # plt.close('all')
+            # plt.figure()
+            # labels_pal = sns.cubehelix_palette(len(set(list_labels)), light=.9, dark=.1, reverse=True, start=0, rot=-2)
+            # labels_lut = dict(zip(map(str, list(set(list_labels))), labels_pal))        
+            # labels_colors = [labels_lut[str(k)] for k in list_labels]
+            # cm_PIR = sns.clustermap(df_PIR,col_cluster=False,row_cluster=True, xticklabels=1, vmin=1, vmax=1.3, row_colors=[Subgroups_of_patients_labels_colors,labels_colors], linewidths=0, cmap="magma")
 
-            # plt.close()
+            # plt.close('all')
             # plt.figure()
             # labels_pal = sns.cubehelix_palette(len(set(list_labels)), light=.9, dark=.1, reverse=True, start=0, rot=-2)
             # labels_lut = dict(zip(map(str, list(set(list_labels))), labels_pal))        
@@ -303,21 +303,21 @@ def differential_abundance_analysis(dataset, heatmapALL, labels, IndexAndClass,i
             # hm = cm_PIR.ax_heatmap.get_position()            
             # plt.setp(cm_PIR.ax_heatmap.yaxis.get_majorticklabels(), fontsize=2)
             # cm_PIR.ax_heatmap.set_position([hm.x0, hm.y0, hm.width*0.1, hm.height])
-            for label in range(len(set(Subgroups_of_patients_labels))):
-                cm_PIR.ax_col_dendrogram.bar(0, 0, color=cp[label], label=names[label], linewidth=0)            
-            cm_PIR.ax_col_dendrogram.legend(title=dataset.experiment_label[0], ncol=4,bbox_to_anchor=(0, 1), loc='upper right')
-            # col = cm_PIR.ax_col_dendrogram.get_position()
-            # cm_PIR.ax_col_dendrogram.set_position([col.x0, col.y0, col.width*0.25, col.height*0.5])            
-            # cm_PIR.ax_heatmap.set_xticklabels(cm_PIR.ax_heatmap.get_xticklabels(), rotation=80,fontsize=3)    
-            plt.savefig(dataset.bioInsights_dir_abundance_analysis_global+'clustermap_Predictive_influence_ratio_per_patient_iter_{}.png'.format(str(dataset.args['epochs'])),dpi=1000)            
+            # for label in range(len(set(Subgroups_of_patients_labels))):
+            #     cm_PIR.ax_col_dendrogram.bar(0, 0, color=cp[label], label=names[label], linewidth=0)            
+            # cm_PIR.ax_col_dendrogram.legend(title=dataset.experiment_label[0], ncol=4,bbox_to_anchor=(0, 1), loc='upper right')
+            # # col = cm_PIR.ax_col_dendrogram.get_position()
+            # # cm_PIR.ax_col_dendrogram.set_position([col.x0, col.y0, col.width*0.25, col.height*0.5])            
+            # # cm_PIR.ax_heatmap.set_xticklabels(cm_PIR.ax_heatmap.get_xticklabels(), rotation=80,fontsize=3)    
+            # plt.savefig(dataset.bioInsights_dir_abundance_analysis_global+'clustermap_Predictive_influence_ratio_per_patient_iter_{}.png'.format(str(dataset.args['epochs'])),dpi=1000)            
 
-            # Display Prediction Index in Unrestricted Model
-            plt.close()
-            plt.figure()
-            real_class_confidence_clrs = [(0,1,0) if rcc>1/len(set(list_labels)) else (1,0,0) for rcc in real_class_confidence]
-            cm = sns.clustermap(pred_Confidence,col_cluster=False,row_cluster=True,vmin=0,vmax=1, 
-                                row_colors=[labels_colors,real_class_confidence_clrs], linewidths=0, cmap="RdYlGn",
-                                row_linkage=cm_PIR.dendrogram_row.linkage)#,figsize=(10,20))                                                
+            # # Display Prediction Index in Unrestricted Model
+            # plt.close('all')
+            # plt.figure()
+            # real_class_confidence_clrs = [(0,1,0) if rcc>1/len(set(list_labels)) else (1,0,0) for rcc in real_class_confidence]
+            # cm = sns.clustermap(pred_Confidence,col_cluster=False,row_cluster=True,vmin=0,vmax=1, 
+            #                     row_colors=[labels_colors,real_class_confidence_clrs], linewidths=0, cmap="RdYlGn",
+            #                     row_linkage=cm_PIR.dendrogram_row.linkage)#,figsize=(10,20))                                                
             # hm = cm.ax_heatmap.get_position()            
             # plt.setp(cm.ax_heatmap.yaxis.get_majorticklabels(), fontsize=2)
             # cm.ax_heatmap.set_position([hm.x0, hm.y0, hm.width*0.25, hm.height])
@@ -326,9 +326,9 @@ def differential_abundance_analysis(dataset, heatmapALL, labels, IndexAndClass,i
             # cm.ax_col_dendrogram.legend(title=dataset.experiment_label[0], loc="best", ncol=5, bbox_to_anchor=(0.47, 0.8), bbox_transform=plt.gcf().transFigure)
             #     col = cm.ax_col_dendrogram.get_position()
             #     cm.ax_col_dendrogram.set_position([col.x0, col.y0, col.width*0.25, col.height*0.5])            
-            cm.savefig(dataset.bioInsights_dir_abundance_analysis+'heatmap_PredictionIndex_iter_{}.png'.format(str(dataset.args['epochs'])),dpi=1000) 
+            # cm.savefig(dataset.bioInsights_dir_abundance_analysis+'heatmap_PredictionIndex_iter_{}.png'.format(str(dataset.args['epochs'])),dpi=1000) 
 
-            return cm_PIR.dendrogram_row.linkage, df_PIR
+            return  
 
         def visualizeRegressionAnalysis_(dataset, dependentVariable,clust,list_labels):
             '''
@@ -348,7 +348,7 @@ def differential_abundance_analysis(dataset, heatmapALL, labels, IndexAndClass,i
                     # data[v][data[v]<2] = (data[v][data[v]<2]/10) + 2
                 
                 # Display and save boxplots of abundance.
-                plt.close()
+                plt.close('all')
                 plt.figure()                                
                 df = pd.DataFrame(dict([ (k,pd.Series(v)) for k,v in data.items() ]))
                 labels_pal = sns.cubehelix_palette(len(set(list_labels)), light=.9, dark=.1, reverse=True, start=0, rot=-2)                
@@ -382,7 +382,7 @@ def differential_abundance_analysis(dataset, heatmapALL, labels, IndexAndClass,i
                 data['Relative abundance'] = np.random.uniform(0,0.00000001,len(data['Relative abundance']))
 
             # Display and save boxplots of abundance.                
-            plt.close()
+            plt.close('all')
             plt.figure()
             df = pd.DataFrame(dict([ (k,pd.Series(v)) for k,v in data.items() ]))
             labels_pal = sns.cubehelix_palette(len(set(list_labels)), light=.9, dark=.1, reverse=True, start=0, rot=-2)
@@ -515,13 +515,13 @@ def differential_abundance_analysis(dataset, heatmapALL, labels, IndexAndClass,i
             #                 break        
             # Show PIRs mean values for patient subgroups
             # if len(heatmap_centroid[list(heatmap_centroid.keys())[0]])>1:
-            #     plt.close()
+            #     plt.close('all')
             #     plt.figure()    
             #     df2 = pd.DataFrame.from_dict(heatmap_centroid).T        
             #     scm = sns.clustermap(df2,row_cluster=True,col_cluster=True,vmin=-2,vmax=2,xticklabels=TME_Names)
             #     plt.savefig(dataset.bioInsights_dir_abundance_analysis_Subgroups+'/Clustermap_SubgroupsDifferencesPIR.png',dpi=600)                                 
             #     # Show TME abundance differences for patient subroups highlighting top2 PIR values.
-            #     plt.close()
+            #     plt.close('all')
             #     plt.figure()    
             #     df2 = pd.DataFrame.from_dict(heatmap_TME)        
             #     ax = sns.clustermap(df2,row_cluster=True,col_cluster=True,vmin=-2,vmax=2,yticklabels=list(heatmap_centroid.keys()))
@@ -570,7 +570,7 @@ def differential_abundance_analysis(dataset, heatmapALL, labels, IndexAndClass,i
             #                     bxplt = {'Patient subgroup':['PS'+str(subgrp_0)]*len(list(df['PIR value'][s1]))+['PS'+str(subgrp_1)]*len(list(df['PIR value'][s2])),'{} PIR values per patient'.format(micro_elem):list(df['PIR value'][s1])+list(df['PIR value'][s2])}
             #                     df_b = pd.DataFrame(dict([ (k,pd.Series(v)) for k,v in bxplt.items() ])) 
             #                     # Display and save boxplots of abundance.                
-            #                     plt.close()
+            #                     plt.close('all')
             #                     plt.figure()
             #                     ax = sns.boxplot(x='Patient subgroup', y='{} PIR values per patient'.format(micro_elem),data=df_b,order=['PS'+str(subgrp_0),'PS'+str(subgrp_1)])#, hue=dataset.experiment_label[0],data=df_b)                
             #                     test_results = add_stat_annotation(ax, data=df_b,x='Patient subgroup', y='{} PIR values per patient'.format(micro_elem),order=['PS'+str(subgrp_0),'PS'+str(subgrp_1)],
@@ -596,7 +596,7 @@ def differential_abundance_analysis(dataset, heatmapALL, labels, IndexAndClass,i
             #                 bxplt = {'PS'+str(subgrp_0):df['PIR value'][s1],
             #                             'PS'+str(subgrp_1):df['PIR value'][s2]}
             #                 df_b = pd.DataFrame(dict([ (k,pd.Series(v)) for k,v in bxplt.items() ])) 
-            #                 plt.close()
+            #                 plt.close('all')
             #                 fig = plt.figure()
             #                 ax = fig.add_subplot(111)
             #                 ax.boxplot([np.array(df['PIR value'][s1]),np.array(df['PIR value'][s2])])
@@ -709,7 +709,7 @@ def differential_abundance_analysis(dataset, heatmapALL, labels, IndexAndClass,i
             patient_Ineach_subgroup, Subgroups_of_patients_labels_names, Subgroups_of_patients_labels, Top1PerPatient = showGroups_Patients(RestrictedModelData,labels,dependentVariable,Top1PerPatient,topKClustersStats,dataset,IndexAndClass)
 
             # Show patient Prediction Confidence
-            linkage, PIR_df = showPatientPredictionConfidence(dataset,pred_Confidence,labels,Subgroups_of_patients_labels_names, Subgroups_of_patients_labels,topKClustersStats,IndexAndClass,Top1PerPatient,real_class_confidence)            
+            showPatientPredictionConfidence(dataset,pred_Confidence,labels,Subgroups_of_patients_labels_names, Subgroups_of_patients_labels,topKClustersStats,IndexAndClass,Top1PerPatient,real_class_confidence)            
         else:
             patient_Ineach_subgroup = []
         
