@@ -80,7 +80,7 @@ def visualize_tsne_phenotypes(dataset, IndexAndClass,clusters):
 
         pheno_assignmnents_75 = np.zeros(pheno_assignmnents.shape[0])
         for ph in range(pheno_assignmnents.shape[1]):
-            thr = np.percentile(pheno_assignmnents[pheno_assignmnents.argmax(1)==ph,ph],90)
+            thr = np.percentile(pheno_assignmnents[:,ph],90)
             pheno_assignmnents_75[np.logical_and(pheno_assignmnents.argmax(1)==ph,pheno_assignmnents[:,ph]>=thr)] = ph+1
         plt.close('all')
         fig, ax = plt.subplots()   
@@ -176,6 +176,43 @@ def load_patch_image(dataset,imList):
 
     return mosaic, labels
 
+def load_patch_image_for_prototypes(dataset,imList):
+    '''
+    Load patch image
+    # Create label map. 
+    labels = []
+    last_patch = 0
+    for im_i in imList:
+        num_patches = int(im_i.shape[0]/dataset.patch_size)*int(im_i.shape[1]/dataset.patch_size)
+        labels.append(np.reshape(np.array(range(last_patch,last_patch+num_patches)),(int(im_i.shape[0]/dataset.patch_size),int(im_i.shape[1]/dataset.patch_size))))
+        last_patch = last_patch+num_patches
+    labels = np.concatenate(labels,1)
+    '''             
+
+    labels = []
+    last_patch = 0
+    x_y_shape = [0,0]
+    for im_i in imList:
+
+        # Create label image
+        num_patches = int(im_i.shape[0]/dataset.patch_size)*int(im_i.shape[1]/dataset.patch_size)
+        labels.append(np.reshape(np.array(range(last_patch,last_patch+num_patches)),(int(im_i.shape[0]/dataset.patch_size),int(im_i.shape[1]/dataset.patch_size))))
+        last_patch = last_patch+num_patches
+
+        # Update shape of mosaic
+        x_y_shape[0], x_y_shape[1] = max(labels[-1].shape[0],x_y_shape[0]), labels[-1].shape[1]+x_y_shape[1]
+            
+    # Create mosaic
+    mosaic = np.zeros(x_y_shape,dtype=np.uint32)+4294967295
+
+    # Concatenate images
+    col=0
+    for lab in labels:
+        mosaic[0:lab.shape[0],col:col+lab.shape[1]] = lab
+        col += lab.shape[1]
+
+    return mosaic, labels
+
 def select_patches_from_cohort_(clusters,dataset,subject_info,count):
 
     # Crops,Confidence,and Phenotype Vector.
@@ -275,7 +312,7 @@ def topk_confident_patches(dataset,n_cell_types,
     K = int(np.ceil(10/dataset.processed_file_names*100))
 
     # Create label map. 
-    labels,labels_list = load_patch_image(dataset,imList)
+    labels,labels_list = load_patch_image_for_prototypes(dataset,imList)
     # for ll in range(len(labels_list)):
     #     labels_list[ll] = np.transpose(labels_list[ll])
     # labels = np.concatenate(labels_list,axis=1)
@@ -464,62 +501,49 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
     return heatmapMarkerExpression, heatmap_Colocalization, heatmap_Size, heatmap_Eccentricity, heatmap_Granularity
 
 def save_heatmap_raw_and_normalized(filename, heatmap, TME_names,Colormap,Marker_Names):    
-    y_ticklabels = TME_names[heatmap.sum(1)!=0]
-    c_map = Colormap[:heatmap.shape[0]][heatmap.sum(1)!=0]
+    y_ticklabels = TME_names
+    c_map = Colormap[:heatmap.shape[0]]
     # Figure Heatmap Raw Values
     plt.close('all')
     plt.figure()
     sns.set(font_scale=0.9)
     cluster=True if (heatmap.sum(1)!=0).sum()>1 else False
-    h_E_Fig = sns.clustermap(heatmap[heatmap.sum(1)!=0,:],col_cluster=cluster, row_cluster=cluster, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels,vmin=-1,vmax=1, linewidths=0.5, cmap="bwr")            
+    h_E_Fig = sns.clustermap(heatmap,col_cluster=cluster, row_cluster=cluster, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels,vmin=-1,vmax=1, linewidths=0.5, cmap="bwr")            
     h_E_Fig.savefig(filename+'_Raw.png',dpi=600) 
 
     # Save Excel.
-    df = pd.DataFrame(heatmap[heatmap.sum(1)!=0,:], columns = Marker_Names)
+    df = pd.DataFrame(heatmap, columns = Marker_Names)
     df.index = y_ticklabels
     df.to_excel(filename+'_Raw.xlsx')  
 
     # Figure Heatmap Min is 0 and max is 1 Values    
-    h_E_COL_MinMax = heatmap[heatmap.sum(1)!=0,:] - heatmap[heatmap.sum(1)!=0,:].min(0,keepdims=True)
+    h_E_COL_MinMax = heatmap - heatmap.min(0,keepdims=True)
     h_E_COL_MinMax = h_E_COL_MinMax/h_E_COL_MinMax.max(0,keepdims=True)
     h_E_COL_MinMax[np.isnan(h_E_COL_MinMax)] = 0 
     plt.close('all')
     plt.figure()
     sns.set(font_scale=0.9)
-    if (h_E_COL_MinMax.sum(1)!=0).sum()==1: # One column heatmap
-        h_E_Fig = sns.clustermap(h_E_COL_MinMax[h_E_COL_MinMax.sum(1)!=0,:],col_cluster=False, 
-            row_cluster=False, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5,vmin=-1,vmax=1, cmap="bwr")            
-        h_E_Fig.savefig(filename+'_MinMax.png',dpi=600) 
-    elif (h_E_COL_MinMax.sum(1)!=0).sum()>1: # Normal heatmap.    
-        h_E_Fig = sns.clustermap(h_E_COL_MinMax[h_E_COL_MinMax.sum(1)!=0,:],col_cluster=True, 
-            row_cluster=True, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5,vmin=-1,vmax=1, cmap="bwr")            
-        h_E_Fig.savefig(filename+'_MinMax.png',dpi=600)  
+    h_E_Fig = sns.clustermap(h_E_COL_MinMax,col_cluster=cluster, 
+        row_cluster=True, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5,vmin=-1,vmax=1, cmap="bwr")            
+    h_E_Fig.savefig(filename+'_MinMax.png',dpi=600)  
     
     # Figure Heatmap z-scored values
-    h_E_COL_Norm = stats.zscore(heatmap[heatmap.sum(1)!=0,:],axis=0)  
+    h_E_COL_Norm = stats.zscore(heatmap,axis=0)  
     h_E_COL_Norm[np.isnan(h_E_COL_Norm)] = 0              
     plt.close('all')
     plt.figure()
     sns.set(font_scale=0.9)    
-    if (h_E_COL_Norm.sum(1)!=0).sum()==1: # One column heatmap
-        h_E_Fig = sns.clustermap(h_E_COL_Norm,col_cluster=False, vmin=-1, vmax=1, row_cluster=False, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5, cmap="bwr")            
-        h_E_Fig.savefig(filename+'_Norm.png',dpi=600) 
-    elif (h_E_COL_Norm.sum(1)!=0).sum()>1: # Normal heatmap
-        h_E_Fig = sns.clustermap(h_E_COL_Norm,col_cluster=True, vmin=-1, vmax=1, row_cluster=True, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5, cmap="bwr")            
-        h_E_Fig.savefig(filename+'_Norm.png',dpi=600) 
+    h_E_Fig = sns.clustermap(h_E_COL_Norm,col_cluster=cluster, vmin=-1, vmax=1, row_cluster=cluster, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5, cmap="bwr")            
+    h_E_Fig.savefig(filename+'_Norm.png',dpi=600) 
 
     # Figure Heatmap z-scored values
-    h_E_COL_Norm = stats.zscore(h_E_COL_Norm[heatmap.sum(1)!=0,:],axis=1)  
+    h_E_COL_Norm = stats.zscore(heatmap,axis=1)  
     h_E_COL_Norm[np.isnan(h_E_COL_Norm)] = 0              
     plt.close('all')
     plt.figure()
-    sns.set(font_scale=0.9)    
-    if (h_E_COL_Norm.sum(1)!=0).sum()==1: # One column heatmap
-        h_E_Fig = sns.clustermap(h_E_COL_Norm,col_cluster=False, vmin=-1, vmax=1, row_cluster=False, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5, cmap="bwr")            
-        h_E_Fig.savefig(filename+'_Norm_rows.png',dpi=600) 
-    elif (h_E_COL_Norm.sum(1)!=0).sum()>1: # Normal heatmap
-        h_E_Fig = sns.clustermap(h_E_COL_Norm,col_cluster=True, vmin=-1, vmax=1, row_cluster=True, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5, cmap="bwr")            
-        h_E_Fig.savefig(filename+'_Norm_rows.png',dpi=600) 
+    sns.set(font_scale=0.9)        
+    h_E_Fig = sns.clustermap(h_E_COL_Norm,col_cluster=cluster, vmin=-1, vmax=1, row_cluster=cluster, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5, cmap="bwr")            
+    h_E_Fig.savefig(filename+'_Norm_rows.png',dpi=600) 
 
 def save_heatMapMarker_and_barplot(dataset, heatmapMarkerExpression, heatmap_Colocalization, heatmap_Size, heatmap_Eccentricity, heatmap_Granularity, CropConf,Marker_Names,cell_type,Thresholds):
     '''
@@ -713,7 +737,7 @@ def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, Clustering
     h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Perc_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
     plt.close('all')
     plt.figure()
-    Neigh_to_Pheno[Neigh_to_Pheno==0] = np.random.rand()*1e-3
+    Neigh_to_Pheno[Neigh_to_Pheno==0] = np.random.rand(Neigh_to_Pheno[Neigh_to_Pheno==0].shape[0])*1e-5
     h_E_Fig = sns.clustermap(Neigh_to_Pheno.transpose(),col_cluster=True, row_cluster=True,vmin=-1, vmax=1, col_colors=row_colors_Neigh, z_score=1,
                                 row_colors=col_colors_Pheno,yticklabels=xticklabels_Pheno,xticklabels=yticklabels_Neigh, linewidths=0.5, cmap="bwr")            
     h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Zscore_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
