@@ -270,10 +270,26 @@ def All_TMEs_in_Image_(clusters,dataset,subject_info):
                 aux = (cell_type_assignment[:Patch_im.max()+1,cell_type]*255).astype(np.uint8)                
                 last_patch = 0
                 aux_2 = []
+                
+                # Shape of images
+                x_y_shape = [0, 0]
+            
                 for im_i in Patch_IMS:
-                    aux_2.append(np.transpose(np.reshape(aux[last_patch:last_patch+im_i.max()-im_i.min()+1],(im_i.shape[1],im_i.shape[0]))))                    
+                    aux_2.append(np.reshape(aux[last_patch:last_patch+im_i.max()-im_i.min()+1],(im_i.shape[0],im_i.shape[1])))
                     last_patch = last_patch+im_i.max()-im_i.min()+1
-                aux = np.concatenate(aux_2,1)                
+
+                    # Upadte sizes of mosaic
+                    x_y_shape[0], x_y_shape[1] = max(aux_2[-1].shape[0],x_y_shape[0]), aux_2[-1].shape[1]+x_y_shape[1]
+
+
+                # Create mosaic
+                aux = np.zeros(x_y_shape)
+
+                # Concatenate images
+                col=0
+                for im_i in aux_2:
+                    aux[0:im_i.shape[0],col:col+im_i.shape[1]] = im_i
+                    col += im_i.shape[1]               
 
                 # Interpolate aux image to match size with the original one.
                 Labels[:,:,cell_type] = cv2.resize(aux, (im.shape[1],im.shape[0]), 0, 0, interpolation = cv2.INTER_NEAREST)        
@@ -288,7 +304,7 @@ def All_TMEs_in_Image_(clusters,dataset,subject_info):
 
             # Save original image
             if dataset.args['Bio_save_Orig_im'] and cell_type_idx==0:                
-                imwrite(dataset.bioInsights_dir_TME_in_image+'{}.tif'.format(subject_info[0]), np.moveaxis(np.concatenate(imList,1),2,0),imagej=True,metadata={'axes': Labels.shape[2], 'unit': 'um','axes': 'CYX'})  
+                imwrite(dataset.bioInsights_dir_TME_in_image+'{}.tif'.format(subject_info[0]), np.moveaxis(im,2,0),imagej=True,metadata={'axes': im.shape[2], 'unit': 'um','axes': 'CYX'})  
 
 
         del im, imList, PCL_reprsntions, Patch_im
