@@ -943,7 +943,6 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         
         if len([i for i in os.listdir(self.bioInsights_dir_cell_types_Neigh) if 'Interactivity' in i])>0 and False:
             return
-
         
         if self.args['TSNE_Perc_Pat']>0:
             visualize_tsne_phenotypes(self, IndexAndClass,clusters)
@@ -968,18 +967,18 @@ class NaroNet_dataset(torch.utils.data.Dataset):
             Visualize all the results.
         '''
 
-        # # Obtain Neigh-to-Pheno, and Area-to-Neigh heatmap.
-        # for ClusteringTrheshold in [0,50,75,90,99]:
-        #     Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)     
+        # Obtain Neigh-to-Pheno, and Area-to-Neigh heatmap.
+        for ClusteringTrheshold in [0,50,75,90,99]:
+            Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)     
 
         # Obtain cell-types examples
         self.ObtainPhenoExamples(IndexAndClass,clusters,[25])                
         
-        # # Cell-types abundances
-        # heatmapClusterPresence, labels = self.clusterPresence(clusters, IndexAndClass,[50], isTraining=False)                        
+        # Cell-types abundances
+        heatmapClusterPresence, labels = self.clusterPresence(clusters, IndexAndClass,[50], isTraining=False)                        
         
-        # # Differential abundance analysis
-        # _, _, _, _, _ = differential_abundance_analysis(self, heatmapClusterPresence, labels, IndexAndClass,False)
+        # Differential abundance analysis
+        _, _, _, _, _ = differential_abundance_analysis(self, heatmapClusterPresence, labels, IndexAndClass,False)
 
         # Apply clusters and attention to images
         All_TMEs_in_Image(self, clusters, IndexAndClass[:int(self.args['Pheno_Perc_Pat']*len(IndexAndClass))])           
