@@ -157,9 +157,9 @@ class pheno(torch.nn.Module):
         self.out_channels = out_channels
 
         # Initialize linear model
-        self.lin1 = torch.nn.Linear(in_channels, int(in_channels/2))        
-        self.lin2 = torch.nn.Linear(int(in_channels/2), int(in_channels/4))        
-        self.lin3 = torch.nn.Linear(int(in_channels/4), out_channels)
+        self.lin1 = torch.nn.Linear(in_channels, in_channels)        
+        self.lin2 = torch.nn.Linear(in_channels, int(in_channels/2))        
+        self.lin3 = torch.nn.Linear(int(in_channels/2), out_channels)
         # self.BN = torch.nn.BatchNorm1d(out_channels)#,track_running_stats=False)                
 
     def reset_parameters(self):
