@@ -122,7 +122,7 @@ class ContrastiveLearningDataset_PCL(Dataset):
                     if data[xIn:xIn+int(self.patch_size*self.alpha_L),yIn:yIn+int(self.patch_size*self.alpha_L),:].sum((2)).max()>=thr[0] and self.args['PCL_eliminate_Black_Background']:                                        
                         images.append(data[xIn:xIn+int(self.patch_size*self.alpha_L),yIn:yIn+int(self.patch_size*self.alpha_L),:])
                         break
-                    elif data[xIn:xIn+int(self.patch_size*self.alpha_L),yIn:yIn+int(self.patch_size*self.alpha_L),:].sum((2)).max()<=thr[0] and self.args['PCL_eliminate_White_Background']:                                        
+                    elif data[xIn:xIn+int(self.patch_size*self.alpha_L),yIn:yIn+int(self.patch_size*self.alpha_L),:].sum((2)).min()<=thr[1] and self.args['PCL_eliminate_White_Background']:                                        
                         images.append(data[xIn:xIn+int(self.patch_size*self.alpha_L),yIn:yIn+int(self.patch_size*self.alpha_L),:])
                         break
                     elif self.args['PCL_eliminate_Black_Background']==False and self.args['PCL_eliminate_White_Background']==False: 
