@@ -55,14 +55,9 @@ def inductiveClustering(self,Indices,index,saveClusters,training,labels,optimize
         for IndicesI in Indices[index:min(index+self.args['batch_size'],len(Indices))]:             
             
             # Obtain the labels of this subject.
-            chosenLabels.append(labels[IndicesI])
+            chosenLabels.append(labels[IndicesI])        
+            subgraphs.append([0]) 
             
-            # If True the subject has a single subgraph, if False obtain the number of subgraphs.
-            if self.dataset.findLastIndex(IndicesI)==0:
-                subgraphs.append([0]) 
-            else:
-                subgraphs.append(list(range(0,self.dataset.findLastIndex(IndicesI)))) 
-        
         return subgraphs, chosenLabels
     
     def print_losses(cell_ent_loss0,cell_ent_loss1,pat_ent0,pat_ent1,args):
