@@ -40,6 +40,8 @@ def parameters(path, debug):
         args['epochs'] = 3 # Number of epochs to run PCL. Increase the number so that all function losses find a plateau without overfitting
         args['weight_decay'] = 0 # Weight Decay used to train the CNN. Do not change this value.
         args['batch_size'] = 12 # Number of subjects used per iteration. A higher batch size results in learning more features and doing it in a more stable way but will require more RAM and GPU memory usage.    
+        args['lr_decay_step_size'] = 0.001 # Learning Rate used to train the CNN. Do not change this value.
+        args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr'] = 0.001 # Learning Rate used to train the CNN. Do not change this value.
         args['dropoutRate'] = 0 # Dropout rate 
         args['training_MODE'] = 'TrainALL' # Train mode selection. 'TrainALL' uses 100% of the data to train (no validation). 'CrossValidation' divides data in k-folds to obtain generability of the model.
@@ -73,7 +75,7 @@ def parameters(path, debug):
         args['TSNE_Perc_Pat'] = 0.5 # Percentage of patients to use to generate the tsne.     
 
 
-    elif 'Melanoma_ProgressionvsBaseline' in path:            
+    elif 'Melanoma' in path:            
         # Patch contrastive learning parameters
         args['PCL_CNN_Architecture']='resnet50' # or resnet18
         args['PCL_N_Workers']=2 # Number of data loading workers 
@@ -94,7 +96,7 @@ def parameters(path, debug):
         args['PCL_Color_perturbation_Augmentation'] = True # Color augmentation for H&E tissue staining.
 
         # Label you want to infer with respect the images.
-        args['experiment_Label'] = ['Sample_Type'] 
+        args['experiment_Label'] = ['Unsupervised'] 
 
         # Architecture Search parameters
         args['num_samples_architecture_search'] = 700  
@@ -116,9 +118,10 @@ def parameters(path, debug):
         args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
 
         # Neural Network
-        args['N_Phenotypes'] = 1 if debug=='Index' else hp.choice('clusters1',[5,8,15,20]) if debug=='Object' else 8     
-        args['N_Neighborhoods'] = 2 if debug=='Index' else hp.choice('clusters2',[6,11,12,21]) if debug=='Object' else 12
-        args['N_Areas'] = 1 if debug=='Index' else hp.choice('clusters3',[2,6,7]) if debug=='Object' else 6      
+        args['N_Phenotypes'] = 8
+        args['N_Neighborhoods'] =16
+        args['N_Areas'] = 4
+        args['n_hops_neighborhoods'] = 1
         args['Phenotype_Learning'] = True  
         args['Neighborhood_Learning'] = True  
         args['Area_Learning'] = True
@@ -136,8 +139,11 @@ def parameters(path, debug):
         args['PatchEntropy_Area'] = 0#.0001#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1                                  
 
         # Bioinsights parameters
-        args['Bio_save_Orig_im'] = False
-        args['TSNE_Perc_Pat'] = 0.33 # Percentage of patients to use to generate the tsne. 
+        args['Bio_save_Orig_im'] = True
+        args['TSNE_Perc_Pat'] = 1 # Percentage of patients to use to generate the tsne. 
+        args['Pheno_Perc_Pat'] = 1 # Percentage of patients to use to generate the tsne. 
+        args['Pheno_Excluded_from_analysis'] = [] # Percentage of patients used to calculate TSNE. 1 is 100% of patients
+        args['Neigh_Excluded_from_analysis'] = [] # Percentage of patients used to calculate TSNE. 1 is 100% of patients
 
 
     elif 'LF_Recurrence' in path:            
@@ -704,7 +710,7 @@ def parameters(path, debug):
         args['PCL_Color_perturbation_Augmentation'] = False # Color augmentation for H&E tissue staining.
 
         # Label you want to infer with respect the images.
-        args['experiment_Label'] = ['Unsupervised'] 
+        args['experiment_Label'] = ['Patient_Status'] 
 
         # Architecture Search parameters
         args['num_samples_architecture_search'] = 1500  
@@ -726,8 +732,8 @@ def parameters(path, debug):
         args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
 
         # Neural Network
-        args['N_Phenotypes'] = 6
-        args['N_Neighborhoods'] = 10
+        args['N_Phenotypes'] = 8
+        args['N_Neighborhoods'] = 12
         args['N_Areas'] = 4
         args['n_hops_neighborhoods'] = 2
         args['Phenotype_Learning'] = True  
@@ -753,6 +759,73 @@ def parameters(path, debug):
         args['Pheno_Excluded_from_analysis'] = [] # Phenotype excluded from the analysis e.g., [1], [3,7] for eliminating phenotype 1 and phenotypes 3 and 7, respectively
         args['Neigh_Excluded_from_analysis'] = [] # Neighborhoods excluded from the analysis e.g., [1], [3,7] for eliminating neighborhood 1 and phenotypes 3 and 7, respectively
 
+    elif 'test_dataset' in path:            
+        
+        # Patch contrastive learning parameters
+        args['PCL_CNN_Architecture']='resnet50' # Architecture of the CNN. Choose between resnet50 or resnet18. resnet50 is slow but is capable of learning more complex patterns. resnet18 is faster but learns simpler patterns. So far we have used resnet50.
+        args['PCL_Learning_Rate']= 0.0003 # Learning Rate used to train the CNN. Do not change this value.
+        args['PCL_Weight_Decay']= 1e-4 # Weight Decay used to train the CNN. Do not change this value.
+        args['PCL_Temperature']= 0.07 # Softmax temperature used to train the CNN. Do not change this value.
+        args['PCL_GPU_INDEX']= torch.device('cuda:0') # Specify the GPU where the training is carried out.
+        args['PCL_Epochs']=100 # Number of epochs to run PCL. Increase the numnber so that PCL achieves at least a 85% of top1 accuracy.
+        args['PCL_N_Workers']=10 # Number of workers used to parallelize data loading. A higher number of workers will result in a faster execution but will require more RAM memory usage. 
+        args['PCL_N_Crops_per_Image']=5 # Number of crops used from each image to train the model in each iteration. Higher number of crops will learn more features from patches from one image but requires more RAM and GPU memory usage.
+        args['PCL_Patch_Size']=5 # Size of image patch (in pixels). We saw best performance when the patch embeds 1 to 3 cells.
+        args['PCL_Stride']=0 # Size of stride between consecutive patches. Do not use it. It is not yet implemented. :(
+        args['PCL_Alpha_L']=1.20 # Size ratio between image crop and image patch. Check paper for better explanation.
+        args['PCL_Z_Score']= True # Whether to apply z_score per channel/marker. Seen better performance when using it. 
+        args['PCL_Batch_Size']= 12 # Number of images used per iteration. A higher batch size results in learning more features and doing it in a more stable way but will require more RAM and GPU memory usage.    
+        args['PCL_Out_Dimensions']= 128 # Feature dimensions of the output image patch. A higher value results in more learned features but requires more RAM and GPU memory usage.
+        args['PCL_eliminate_Black_Background'] = False # Whether to eliminate from the training the black background. Use it for Multiplex fluorescence images.
+        args['PCL_eliminate_White_Background'] = False # Whether to eliminate from the training the whit background. Use it for H&E white-field microscopy images.        
+        args['PCL_Color_perturbation_Augmentation'] = False # Whether to use color normalization augmentation in H&E white-field microscopy images. Used to force PCL to learn morphological features and avoid learning color staining features. 
+
+        # Experiment name used to differentiate subject types (i.e., name of the column from Image_Labels.xslx).
+        args['experiment_Label'] = ['Subject_type'] 
+
+        # General parameters used for Machine Learning
+        args['NaroNet_n_workers'] = 10 # Number of workers used to parallelize data loading. A higher number of workers will result in a faster execution but will require more RAM memory usage. 
+        args['epochs'] = 100 # Number of epochs to run PCL. Increase the number so that all function losses find a plateau without overfitting
+        args['weight_decay'] = 0 # Weight Decay used to train the CNN. Do not change this value.
+        args['batch_size'] = 16 # Number of subjects used per iteration. A higher batch size results in learning more features and doing it in a more stable way but will require more RAM and GPU memory usage.    
+        args['lr_decay_step_size'] = 0.001 # Learning Rate used to train the CNN. Do not change this value.
+        args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
+        args['lr'] = 0.001 # Learning Rate used to train the CNN. Do not change this value.
+        args['dropoutRate'] = 0 # Dropout rate 
+        args['training_MODE'] = 'TrainALL' # Train mode selection. 'TrainALL' uses 100% of the data to train (no validation). 'CrossValidation' divides data in k-folds to obtain train-test parformance of the model.
+        args['folds'] = 1 # Number of folds used in the cross-validation training/testing mode. Check https://machinelearningmastery.com/k-fold-cross-validation/ for more info. 
+        args['device'] = 'cuda:0' # Specify the GPU where the training is carried out.
+        args['Batch_Normalization'] = True # Whether to apply batch normalization just before patch assignment. Do not change this value. If False it will not work.
+        args['dataAugmentationPerc'] = 0 # Artificially augment subjects in each iteration. Value specifies percentage of nodes of the graph changed where 1 stands for 100% and 0 implies no data augmentation used.
+            
+        # NaroNet specific parameters
+        args['N_Phenotypes'] = 3 # Number of local phenotypes. Use low values when you want to find only 2 or 3 relevant phenotypes. Use larger values to find multiple relevant phenotypes.
+        args['N_Neighborhoods'] = 4 # Number of cellular neighborhoods. Use low values when you want to find only 2 or 3 relevant neighborhoods. Use larger values to find multiple relevant neighborhoods.
+        args['N_Areas'] = 2 # Number of tissue areas. Use low values when you want to find only 2 or 3 ares. Use larger values to find multiple relevant areas.     
+        args['n_hops_neighborhoods'] = 1 # Number of hops used to learn neighborhoods using GNNs. Do not change this value.
+        args['Phenotype_Learning'] = True # Whether to learn phenotypes or not  
+        args['Neighborhood_Learning'] = True # Whether to learn neighborhoods or not
+        args['Area_Learning'] = True # Whether to learn areas or not        
+        args['attntnThreshold'] = 0 # Attention threshold for patch assignment. Patches with a confidence value below this are not considered for subject prediction
+        args['1Patch1Cluster'] = False # Whether to let patches be assigned to several TMEs at the same time or not.
+
+        # Contrast accuracy loss. Used to force learned TMEs to be composed of patches with similar features.
+        args['ContrastACC_Pheno'] = 1000 # Multiplication factor for phenotypes. 
+        args['ContrastACC_Neigh'] = 1000 # Multiplication factor for neighborhoods.
+        args['ContrastACC_Area'] = 0 # Multiplication factor for contrast accuracy loss for neighborhoods.
+        args['Perc_high_conf_patches'] = 0.0001 # 1 is 100% and 0.01 is 1%. Great values generates phenotypes and neighborhoods with many patches. Low values generate rare populations.
+
+        # Patch entropy loss. Used to force learned TMEs to be composed of patches with high confidence.
+        args['PatchEntropy_Pheno'] = 0 # Multiplication factor for phenotypes.
+        args['PatchEntropy_Neigh'] = 0 # Multiplication factor for neighborhoods.
+        args['PatchEntropy_Area'] = 1 # Multiplication factor for areas. 
+                
+        # Bioinsights parameters
+        args['Bio_save_Orig_im'] = True # Whether to save the original image in Locate_TME_image. Useful when subjects are composed of several images.
+        args['TSNE_Perc_Pat'] = 1 # Percentage of subjects used to calculate TSNE. 1 is 100% of subjects
+        args['Pheno_Perc_Pat'] = 1 # Percentage of subjects used to calculate TSNE. 1 is 100% of subjects
+        args['Pheno_Excluded_from_analysis'] = [] # Phenotype/s excluded from analysis. (e.g. if [10], P10 is excluded from analysis, if [7,10], P7 and P10 are excluded)
+        args['Neigh_Excluded_from_analysis'] = [] # Neighborhood/s excluded from analysis. (e.g. if [10], N10 is excluded from analysis, if [7,10], N7 and N10 are excluded)alculate TSNE. 1 is 100% of patients
 
     else:
         
